cryovit.config
==============

.. automodule:: cryovit.config

   
   .. rubric:: Functions

   .. autosummary::
   
      validate_dino_config
      validate_experiment_config
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseDataModule
      BaseExperimentConfig
      BaseModel
      BaseTrainer
      DinoFeaturesConfig
      ExperimentPaths
   